@@ -1,7 +1,7 @@
-/* $Id: MuffinFrame.java,v 1.7 1999/05/27 06:10:00 boyns Exp $ */
+/* $Id: MuffinFrame.java,v 1.10 2000/01/25 06:56:52 boyns Exp $ */
 
 /*
- * Copyright (C) 1996-99 Mark R. Boyns <boyns@doit.org>
+ * Copyright (C) 1996-2000 Mark R. Boyns <boyns@doit.org>
  *
  * This file is part of Muffin.
  *
@@ -92,9 +92,10 @@ public class MuffinFrame extends Frame
 	    Image image;
 	    MediaTracker tracker = new MediaTracker(this);
 	    URL url = getClass().getResource("/images/mufficon.jpg");
-	    if (url != null)
+	    Object obj;
+	    if (url != null && ((obj = url.getContent()) instanceof ImageProducer))
 	    {
-		image = Toolkit.getDefaultToolkit().createImage((ImageProducer) url.getContent());
+		image = Toolkit.getDefaultToolkit().createImage((ImageProducer) obj);
 		tracker.addImage(image, 1);
 		tracker.waitForAll();
 		setIconImage(image);
